@@ -1,6 +1,6 @@
 #!/usr/bin/perl -w
 use strict;
-use v5.10;
+use 5.008003;
 use Carp;
 
 use Config;
@@ -16,16 +16,15 @@ use lib catdir( $FindBin::Bin, 'lib' );
 use lib catdir( $FindBin::Bin, updir(), 'lib' );
 use lib catdir( $FindBin::Bin, updir(), 'lib', 'inc' );
 
+use fallback catdir($FindBin::Bin, updir(), 'lib', 'inc'), catdir($FindBin::Bin, updir(), 'lib', 'inc');
+
 use System::Info;
 use Test::Smoke::Util qw(do_pod2usage whereis);
 use Test::Smoke::Util::FindHelpers ':all';
 
-use vars qw($conf);
-our $VERSION = '0.092';
-
-use constant REPO_HOST    => 'github.com';
-use constant GH_REPO_PATH => 'Perl/perl5';
-use constant SNAP_HOST    => 'dromedary.p5h.org:5872';
+# $Id$
+use vars qw($VERSION $conf);
+$VERSION = '0.090';
 
 use Getopt::Long;
 my %options = (
@@ -65,10 +64,10 @@ foreach my $opt (qw( config jcl log )) {
     unless ( $load_error ) {
         $options{oldcfg} = 1;
         print "Using '$options{config}' for defaults.\n";
-        if ( $conf->{perl_version} =~ m{^ 5 \. (?<minorv>\d+) \. .+$}x) {
-            my $is_dev = ($+{minorv}||0) % 2 ? 1 : 0;
-            $conf->{perl_version} = 'blead' if $is_dev;
-        }
+        $conf->{perl_version} eq '5.9.x'  and $conf->{perl_version} = 'blead';
+        $conf->{perl_version} eq '5.11.x' and $conf->{perl_version} = 'blead';
+        $conf->{perl_version} eq '5.13.x' and $conf->{perl_version} = 'blead';
+        $conf->{perl_version} eq '5.15.x' and $conf->{perl_version} = 'blead';
     }
 
     if ( $load_error || $options{default} ) {
@@ -116,9 +115,9 @@ or regenerate from previous _config:
 Current options:
 
   -d dfvalsprefix   Set prefix for a _dfconfig file (<prefix>)
-  -c configprefix   When omitted 'perlcurrent' is used
-  -j jclprefix      When omitted 'perlcurrent' is used
-  -l logprefix      When omitted 'perlcurrent' is used
+  -c configprefix   When ommited 'perlcurrent' is used
+  -j jclprefix      When ommited 'perlcurrent' is used
+  -l logprefix      When ommited 'perlcurrent' is used
   -p prefix         Set -c and -j and -l at once
 
   -des              confirm all answers (needs previous _config)
@@ -138,7 +137,7 @@ my $syncmsg = join "\n", @{ {
     rsync    => "\trsync - Use the rsync(1) program",
     copy     => "\tcopy - Use File::Copy to copy from a local directory",
     hardlink => "\thardlink - Copy from a local directory using link()",
-#    snapshot => "\tsnapshot - Get a snapshot using Net::FTP (or LWP::Simple)",
+    snapshot => "\tsnapshot - Get a snapshot using Net::FTP (or LWP::Simple)",
 } }{ @syncers };
 my @untars = get_avail_tar();
 my $untarmsg = join "", map "\n\t$_" => @untars;
@@ -147,15 +146,15 @@ my %vdirs = map {
     my $vdir = $_;
     is_vms and $vdir =~ tr/.//d;
     ( $_ => $vdir )
-} qw( 5.18.x 5.20.x 5.22.x 5.24.x 5.26.x );
+} qw( 5.18.x 5.20.x 5.22.x );
 
 my %versions = (
-    '5.26.x' => {
-        gbranch => 'maint-5.26',
-        source  => sprintf("%s::perl-5.26.x", SNAP_HOST),
-        server  => sprintf('https://%s/%s/tree/maint-5.26', REPO_HOST, GH_REPO_PATH),
-        sdir    => '/archive/',
-        sfile   => 'maint-5.26.zip',
+    '5.18.x' => {
+        gbranch => 'maint-5.18',
+        source  => 'perl5.git.perl.org::perl-5.18.x',
+        server  => 'http://perl5.git.perl.org',
+        sdir    => '/perl.git/snapshot/refs/heads/',
+        sfile   => 'maint-5.18.tar.gz',
         pdir    => '/pub/apc/perl-current-diffs',
         ddir    => File::Spec->catdir(
             cwd(),
@@ -163,7 +162,7 @@ my %versions = (
             'perl-current'
         ),
 
-        text    => 'Perl 5.26 maint',
+        text    => 'Perl 5.18 maint',
         cfg     => (
             is_win32
                 ? 'w32current.cfg'
@@ -171,12 +170,12 @@ my %versions = (
         ),
         is56x   => 0,
     },
-    '5.28.x' => {
-        gbranch => 'maint-5.28',
-        source  => sprintf("%s::perl-5.28.x", SNAP_HOST),
-        server  => sprintf('https://%s/%s/tree/maint-5.28', REPO_HOST, GH_REPO_PATH),
-        sdir    => '/archive/',
-        sfile   => 'maint-5.28.zip',
+    '5.20.x' => {
+        gbranch => 'maint-5.20',
+        source  => 'perl5.git.perl.org::perl-5.20.x',
+        server  => 'http://perl5.git.perl.org',
+        sdir    => '/perl.git/snapshot/refs/heads/',
+        sfile   => 'maint-5.20.tar.gz',
         pdir    => '/pub/apc/perl-current-diffs',
         ddir    => File::Spec->catdir(
             cwd(),
@@ -184,7 +183,7 @@ my %versions = (
             'perl-current'
         ),
 
-        text    => 'Perl 5.28 maint',
+        text    => 'Perl 5.20 maint',
         cfg     => (
             is_win32
                 ? 'w32current.cfg'
@@ -192,12 +191,12 @@ my %versions = (
         ),
         is56x   => 0,
     },
-    '5.30.x' => {
-        gbranch => 'maint-5.30',
-        source  => sprintf("%s::perl-5.30.x", SNAP_HOST),
-        server  => sprintf('https://%s/%s/tree/maint-5.30', REPO_HOST, GH_REPO_PATH),
-        sdir    => '/archive/',
-        sfile   => 'maint-5.30.zip',
+    '5.22.x' => {
+        gbranch => 'maint-5.22',
+        source  => 'perl5.git.perl.org::perl-5.22.x',
+        server  => 'http://perl5.git.perl.org',
+        sdir    => '/perl.git/snapshot/refs/heads/',
+        sfile   => 'maint-5.22.tar.gz',
         pdir    => '/pub/apc/perl-current-diffs',
         ddir    => File::Spec->catdir(
             cwd(),
@@ -205,7 +204,7 @@ my %versions = (
             'perl-current'
         ),
 
-        text    => 'Perl 5.30 maint',
+        text    => 'Perl 5.22 maint',
         cfg     => (
             is_win32
                 ? 'w32current.cfg'
@@ -215,10 +214,10 @@ my %versions = (
     },
     'blead' => {
         gbranch => 'blead',
-        source  => sprintf("%s::perl-current", SNAP_HOST),
-        server  => sprintf('https://%s/%s.git', REPO_HOST, GH_REPO_PATH),
-        sdir    => '/archive/',
-        sfile   => 'blead.zip',
+        source  => 'perl5.git.perl.org::perl-current',
+        server  => 'http://perl5.git.perl.org',
+        sdir    => '/perl.git/snapshot/',
+        sfile   => '',
         pdir    => '/pub/apc/perl-current-diffs',
         ddir    => File::Spec->catdir(
             cwd(),
@@ -226,7 +225,7 @@ my %versions = (
             'perl-current'
         ),
 
-        text    => 'Perl 5.28 to-be',
+        text    => 'Perl 5.22 to-be',
         cfg     => (
             is_win32
                 ? 'w32current.cfg'
@@ -375,7 +374,7 @@ my %opt = (
     gitorigin => {
         msg => "Git main repository?",
         alt => [ ],
-        dft => sprintf('https://%s/%s.git', REPO_HOST, GH_REPO_PATH),
+        dft => 'git://perl5.git.perl.org/perl.git',
     },
     gitdir => {
         msg => "Directory for the local git repository?",
@@ -512,7 +511,7 @@ Send smoke results to the SmokeDB? (url)
 \t(Leave empty for no.)
 EOT
         alt => [ ],
-        dft => 'https://perl5.test-smoke.org/report',
+        dft => 'http://perl5.test-smoke.org/report',
     },
     send_log => {
         msg => 'Do you want to send the logfile with the report?',
@@ -530,11 +529,6 @@ EOT
         dft => undef,
     },
 
-    hostname => {
-        msg => 'Use the hostname option to override System::Info->hostname',
-        alt => [ ],
-        dft => undef,
-    },
     # user_note
     user_note => {
         msg => "",
@@ -559,7 +553,7 @@ EOT
     mail => {
         msg => "Would you like to email your reports?",
         alt => [qw( N y )],
-        dft => 'N',
+        dft => 'n',
     },
     mail_type => {
         msg => 'Which send facility should be used?',
@@ -878,64 +872,6 @@ you will need to confirm your choice.
     }
 }
 
-=item w32args
-
-For MSWin32 we need some extra information that is passed to
-L<Test::Smoke::Smoker> in order to compensate for the lack of
-B<Configure>.
-
-See L<Test::Smoke::Util/"Configure_win32( )"> and L<tsw32configure.pl>
-
-=cut
-
-WIN32: {
-    last WIN32 unless is_win32;
-
-    my $osvers = get_Win_version();
-    my %compilers = get_avail_w32compilers();
-    my $compiler_info = join(
-        "\n",
-        map {
-            sprintf("  %-4s - %s", $_, $compilers{$_}->{ccbin})
-        } keys %compilers
-    );
-
-    my $dft_compiler = $conf->{w32cc} ? $conf->{w32cc} : "";
-    $dft_compiler ||= ( sort keys %compilers )[-1];
-    $opt{w32cc} = {
-        msg => 'What compiler should be used?',
-        alt => [ keys %compilers ],
-        dft => $dft_compiler,
-    };
-
-    print <<EO_MSG;
-
-You are on $^O ($osvers).
-We found compilers:
-$compiler_info
-EO_MSG
-
-    $config{w32cc} = uc prompt( 'w32cc' );
-    my $cc_info = $compilers{ $config{w32cc} };
-
-    $opt{w32make} = {
-        alt => $cc_info->{maker},
-        dft => ( sort @{ $cc_info->{maker} } )[-1],
-    };
-    $opt{w32make}->{msg} = @{ $compilers{ $config{w32cc} }->{maker} } > 1
-        ? "Which make should be used" : undef;
-
-    $config{w32make} = prompt( 'w32make' );
-    $config{testmake} = $config{testmake};
-
-    $config{w32args} = [
-        "--win32-cctype" => $config{w32cc},
-        "--win32-maker"  => $config{w32make},
-        "osvers=$osvers",
-        $cc_info->{ccversarg},
-    ];
-}
-
 =item cfg
 
 C<cfg> is the path to the file that holds the build-configurations.
@@ -1121,18 +1057,13 @@ SYNCER: {
         $opt{$arg}{dft} = "$options{prefix}.gitbranch";
         $config{$arg} = prompt_file($arg, 1);
 
-        if ($config{$arg}) {
-            if (open my $gb, '>', $config{gitbranchfile}) {
-                print {$gb} $config{gitdfbranch};
-                close $gb;
-                print "Wrote $config{gitbranchfile}...\n";
-            }
-            else {
-                print "Error writing to $config{gitbranchfile}: $!\n";
-            }
+        if (open my $gb, '>', $config{gitbranchfile}) {
+            print {$gb} $config{gitdfbranch};
+            close $gb;
+            print "Wrote $config{gitbranchfile}...\n";
         }
         else {
-            print "Skip '$arg' (no filename)\n";
+            print "Error writing to $config{gitbranchfile}: $!\n";
         }
 
         last SYNCER;
@@ -1264,19 +1195,6 @@ SKIP_TESTS: {
     }
 }
 
-=item hostname
-
-In the case C<< System::Info->hostname >> needs to be overridden.
-
-=cut
-
-HOSTNAME: {
-    $arg = 'hostname';
-    my $hostname = System::Info::si_uname('n');
-    $opt{$arg}{msg} .= "\n   Leave empty to use default '$hostname'";
-    $config{$arg} = prompt($arg);
-}
-
 =item user_note
 
 This gives you a way of adding personal information to the report.
@@ -1349,7 +1267,7 @@ C<< $ENV{PERLIO} = "perlio"; >>). This feature should only be used with
 UTF8 locales, that is why this is checked (by regex only).
 
 B<If you know of a way to get the utf8 locales on your system, which is
-not covered here, please let me know!>
+not coverd here, please let me know!>
 
 =cut
 
@@ -1435,7 +1353,7 @@ See L<Test::Smoke::Mailer> and L<mailrpt.pl>
 =cut
 
 $arg = 'mail';
-$opt{ $arg }{dft} = $options{usedft};
+$opt{ $arg }{dft} = ! $options{usedft};
 $config{ $arg } = prompt_yn( $arg );
 MAIL: {
     last MAIL unless $config{mail};
@@ -1502,6 +1420,56 @@ MAIL: {
     }
 }
 
+=item w32args
+
+For MSWin32 we need some extra information that is passed to
+L<Test::Smoke::Smoker> in order to compensate for the lack of
+B<Configure>.
+
+See L<Test::Smoke::Util/"Configure_win32( )"> and L<W32Configure.pl>
+
+=cut
+
+WIN32: {
+    last WIN32 unless is_win32;
+
+    my $osvers = get_Win_version();
+    my %compilers = get_avail_w32compilers();
+
+    my $dft_compiler = $conf->{w32cc} ? $conf->{w32cc} : "";
+    $dft_compiler ||= ( sort keys %compilers )[-1];
+    $opt{w32cc} = {
+        msg => 'What compiler should be used?',
+        alt => [ keys %compilers ],
+        dft => $dft_compiler,
+    };
+
+    print <<EO_MSG;
+
+I see you are on $^O ($osvers).
+No problem, but we need extra information.
+EO_MSG
+
+    $config{w32cc} = uc prompt( 'w32cc' );
+
+    $opt{w32make} = {
+        alt => $compilers{ $config{w32cc} }->{maker},
+        dft => ( sort @{ $compilers{ $config{w32cc} }->{maker} } )[-1],
+    };
+    $opt{w32make}->{msg} = @{ $compilers{ $config{w32cc} }->{maker} } > 1
+        ? "Which make should be used" : undef;
+
+    $config{w32make} = prompt( 'w32make' );
+    $config{testmake} = $config{testmake};
+
+    $config{w32args} = [
+        "--win32-cctype" => $config{w32cc},
+        "--win32-maker"  => $config{w32make},
+        "osvers=$osvers",
+        $compilers{ $config{w32cc} }->{ccversarg},
+    ];
+}
+
 =item vmsmake
 
 Get the make program to use for VMS (MMS or MMK). Start with the one
@@ -1895,7 +1863,7 @@ sub sort_configkeys {
         qw( makeopt testmake harnessonly hasharness3 harness3opts ),
 
         # user_notes
-        qw( hostname user_note un_file un_position ),
+        qw( user_note un_file un_position ),
 
         # ENV stuff
         qw( perl5lib delay_report ),
@@ -2386,7 +2354,6 @@ sub check_buildcfg {
 
     print "Checking '$file_name'\n     for $pversion on $uname_s\n";
 
-    my @must_option = ( );
     my @no_option = ($pversion eq 'blead') ||($pversion >= 5.009)
         ? ( '-Uuseperlio' )
         : ( );
@@ -2406,14 +2373,6 @@ sub check_buildcfg {
 
         $os =~ /mswin32/i && do {
             push @no_option, qw( -Duselargefiles ) if $config{is56x};
-
-            my %compilers = get_avail_w32compilers();
-            my $cc_info = $compilers{ $config{w32cc} };
-            # Add -DCCHOME=C:\Strawberry\c for strawberryperl-gcc
-            if ($cc_info->{ccversarg} =~ /strawberryperl/i) {
-                (my $cchome = $cc_info->{ccbin}) =~ s{.bin.gcc\.exe$}{}i;
-                push @must_option, "-DCCHOME=$cchome";
-            }
         };
 
         $os =~ /cygwin/i && do {
@@ -2424,10 +2383,6 @@ sub check_buildcfg {
     foreach my $option ( @no_option ) {
         !/^#/ && /\Q$option\E/ && s/^/#/ for @bcfg;
     }
-    foreach my $option ( @must_option ) {
-        unshift @bcfg, ("==\n", "$option\n", "==\n")
-            unless grep { /^\Q$option\E/ } @bcfg;
-    }
 
     my $newcfg = join "", grep !/^#/ => @bcfg;
     return if $oldcfg eq $newcfg;
